import { useEffect, useRef } from 'react';
import { InvalidStateException } from 'dc';
import { baseMixin } from '../mixins';
import { combineMixins } from '../utils';
export function useChart(chartFunc, props) {
  var mixin = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : combineMixins([baseMixin]);
  var chartRef = useRef(null);
  var chart = useRef(null);
  var isRendered = useRef(false);
  useEffect(function () {
    chart.current = chartFunc(chartRef.current);
    isRendered.current = false;
  }, [chartFunc]);
  useEffect(function () {
    if (!chart.current) return;
    mixin && mixin(chart.current, props);

    if (!isRendered.current) {
      try {
        chart.current.render();
        isRendered.current = true;
      } catch (e) {
        if (!(e instanceof InvalidStateException)) throw e;
      }
    } else {
      chart.current.redraw();
    }
  }, [chartFunc, props, mixin]);
  return [chart, chartRef];
}